using SlatedGameToolkit.Framework;
using SlatedGameToolkit.Framework.StateSystem;
using SlatedGameToolkit.Tools.System;
using SlatedGameToolkit.Tools.System.Interaction;
using SlatedGameToolkit.Tools.Utilities.GraphicalPlayground;

namespace SlatedGameToolkit.Tools.Commands
{
    public class GraphicalPlaygroundCommand : IInvocable
    {
        private readonly string[] invokers = new string[] {"playground"};

        public bool Execute(IInteractable interactable, string[] args)
        {
            if (args.Length != 1) return false;
            if (args[0].Equals("start")) {
                if (GameEngine.Running) {
                    interactable.Tell("Engine is already running!");
                    return true;
                }
                Manager manager = new Manager("main state", new MainState());
                GameEngine.Ignite(manager);
                return true;
            } else if (args[0].Equals("stop")) {
                if (!GameEngine.Running) {
                    interactable.Tell("Engine was never running!");
                    return true;
                }
                GameEngine.Stop();
                return true;
            } else if (args[0].Equals("status")) {
                interactable.Tell("Running: " + GameEngine.Running);
                interactable.Tell("Target FPS: " + GameEngine.targetFPS);
                interactable.Tell("Target Update Rate: " + GameEngine.UpdatesPerSecond);
                return true;
            }
            return false;
        }

        public string getDescription()
        {
            return "Starts and stops the graphical playground.";
        }

        public string[] GetInvokers()
        {
            return invokers;
        }

        public string getUsage(string arg)
        {
            return "Usage: \"playground [start | stop | status]\" the required argument being whether to start, stop or get the current status of the game engine.";
        }

        public void Dispose()
        {
            GameEngine.Stop();
        }
    }
}